@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -302,7 +302,14 @@ void Event::Execute( View *view ) {
     }
     break; }
   case EVENT_DESTROY_UNIT: {
-    Unit *u = mis->GetUnit( e_data[0] );
+    Unit *u;
+
+    if ( e_data[0] >= 0 ) {
+      u = mis->GetUnit( e_data[0] );
+    } else {
+      u = mis->GetMap().GetUnit( mis->GetMap().Index2Hex( e_data[2] ) );
+    }
+
     if ( u && ((e_data[1] == -1) ||
         (u->Owner() && (e_data[1] == u->Owner()->ID())))) {
       Point p = u->Position();
