@@ -997,9 +997,11 @@ Unit *Game::MoveUnit( Unit *u, const Point &dest ) {
     undo.Register( u );
     RemoveUnit( u );
 
-    short step;
-    while ( (step = path.GetStep( u->Position() )) != -1)
-      MoveUnit( u, (Direction)step );
+    short step, n = 0;
+    while ( (step = path.GetStep( u->Position() )) != -1) {
+      MoveUnit( u, (Direction)step, (n < 2) );
+      ++n;
+    }
 
     if ( sfx ) sfx->Stop();
 
@@ -1025,12 +1027,14 @@ Unit *Game::MoveUnit( Unit *u, const Point &dest ) {
 ////////////////////////////////////////////////////////////////////////
 // NAME       : Game::MoveUnit
 // DESCRIPTION: Move a unit one hex in a given direction.
-// PARAMETERS : u   - unit to be moved
-//              dir - direction
+// PARAMETERS : u     - unit to be moved
+//              dir   - direction
+//              blink - if TRUE make target cursor blink (default is
+//                      FALSE)
 // RETURNS    : 0 on success, -1 on error
 ////////////////////////////////////////////////////////////////////////
 
-int Game::MoveUnit( Unit *u, Direction dir ) {
+int Game::MoveUnit( Unit *u, Direction dir, bool blink /* = false */ ) {
   MapView *mv = mwin->GetMapView();
   Map *map = mv->GetMap();
   const Point &pos = u->Position();
@@ -1042,7 +1046,7 @@ int Game::MoveUnit( Unit *u, Direction dir ) {
   if ( mv->Enabled() &&
        (mv->HexVisible(pos) || mv->HexVisible(posnew)) )
     mwin->MoveHex( u->Image(), mission->GetUnitSet(),
-                   pos, posnew, ANIM_SPEED_UNIT );
+                   pos, posnew, ANIM_SPEED_UNIT, blink );
 
   u->SetPosition( posnew.x, posnew.y );
   if ( !u->IsDummy() ) {
@@ -1537,6 +1541,7 @@ void Game::SelectCommand( const Point &hex ) {
       } else if ( unit->CanHit( u ) ) {   // attack the unit
         mission->RegisterBattle( unit, u );
         DeselectUnit();
+        mwin->FlashUnit( u->Position(), 2 );
         undo.Disable();
       }
     } else MoveUnit( unit, hex );  // try to move there
