@@ -80,7 +80,7 @@ public:
 
   void SetCursor( const Point &cursor ) const;
   Unit *MoveUnit( Unit *u, const Point &dest );
-  int MoveUnit( Unit *u, Direction dir );
+  int MoveUnit( Unit *u, Direction dir, bool blink = false );
   void SelectUnit( Unit *u );
   void DeselectUnit( bool update = true );
 
