@@ -567,17 +567,19 @@ void History::ReplayAttackEvent( const HistEvent &event, MapWindow *mapwin ) {
                              (u->Position().y + event.data[2]) / 2) );
       mapwin->Show( *mv );
     }
+
+    Point target( event.data[1], event.data[2]);
     mv->SetCursorImage( IMG_CURSOR_HIGHLIGHT );
     Rect upd = mv->SetCursor( u->Position() );
     mapwin->Show( upd );
     mv->SetCursorImage( IMG_CURSOR_ATTACK );
-    upd = mv->SetCursor( Point(event.data[1], event.data[2]) );
+    upd = mv->SetCursor( target );
     mapwin->Show( upd );
+    mapwin->FlashUnit ( target, 2 );
     mv->SetCursor( Point(-1,-1) );
-    SDL_Delay( delay );
     upd = mv->UpdateHex( u->Position() );
     mapwin->Show( upd );
-    upd = mv->UpdateHex( Point(event.data[1], event.data[2]) );
+    upd = mv->UpdateHex( target );
     mapwin->Show( upd );
     lastunit = u;
   }
