@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -49,6 +49,12 @@ enum {
 #define MAPTYPE_CAMPAIGN 1
 #define MAPTYPE_SAVE     2
 
+#ifdef _WIN32_WCE
+# define OW_OK_BUTTON_FLAGS  0
+#else
+# define OW_OK_BUTTON_FLAGS WIDGET_DEFAULT
+#endif
+
 extern Options CFOptions;
 
 ////////////////////////////////////////////////////////////////////////
@@ -402,7 +408,7 @@ GUI_Status InitWindow::StartGame( const char *filename ) {
   }
 
 #ifndef DISABLE_NETWORK
-  if ( CFOptions.IsNetwork() || (game && m->GetFlags() & GI_NETWORK) ) {
+  if ( CFOptions.IsNetwork() ) {
     int err;
     TCPConnection *connection = new TCPConnection();
 
@@ -895,7 +901,8 @@ void GenericOptionsWindow::SetLayout( unsigned short w, unsigned short h ) {
   Window::SetSize( w + 10, h + lfont->Height() + sfont->Height() + 25 );
 
   Widget *wd = new ButtonWidget( B_ID_OK, 1, Height() - sfont->Height() - 9,
-                   Width() - 2, sfont->Height() + 8, WIDGET_DEFAULT, MSG(MSG_B_OK), this );
+                   Width() - 2, sfont->Height() + 8, OW_OK_BUTTON_FLAGS,
+                   MSG(MSG_B_OK), this );
   wd->SetHook( this );
 }
 
@@ -1464,8 +1471,6 @@ void SoundOptionsWindow::Draw( void ) {
 
 #ifndef DISABLE_NETWORK
 
-#define DEFAULT_PORT  9999
-
 ////////////////////////////////////////////////////////////////////////
 // NAME       : NetworkSetupWindow::NetworkSetupWindow
 // DESCRIPTION: Ask user for network parameters. If we are hosting the
@@ -1509,14 +1514,15 @@ NetworkSetupWindow::NetworkSetupWindow( bool server, View *view ) :
   if (!server) {
     address = new StringWidget( 0, wdx, wdy,
               w - wdx - 15, wdh,
-              "localhost", 40, WIDGET_ALIGN_LEFT,
+              CFOptions.GetRemoteName(), 40, WIDGET_ALIGN_LEFT,
               ip_label, this );
     wdy += address->Height() + 5;
   }
 
   port = new NumberWidget( 0, wdx, wdy,
-         sfont->Width() * 5 + 20, wdh, DEFAULT_PORT, 1, 65536,
-         WIDGET_ALIGN_LEFT, port_label, this );
+         sfont->Width() * 5 + 20, wdh,
+         server ? CFOptions.GetLocalPort() : CFOptions.GetRemotePort(),
+         1, 65536, WIDGET_ALIGN_LEFT, port_label, this );
 
   Widget *ok = new ButtonWidget( 0, 1, h - wdh - 1, (w - 2) / 2, wdh,
                WIDGET_DEFAULT, MSG(MSG_B_OK), this );
@@ -1630,6 +1636,12 @@ GUI_Status NetworkSetupWindow::WidgetActivated( Widget *button, Window *win ) {
       (port->String() == NULL)) {
     Audio::PlaySfx( Audio::SND_GUI_ERROR, 0 );
   } else {
+    if ( server )  {
+      CFOptions.SetLocalPort( port->Number() );
+    } else {
+      CFOptions.SetRemoteName( address->String() );
+      CFOptions.SetRemotePort( port->Number() );
+    }
     rc = (GUI_Status)button->ID();
   }
 
