@@ -1,5 +1,5 @@
 // Crimson Fields -- a hex-based game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -230,14 +230,14 @@ static View *init( GUIOptions &opts ) {
     File datfile( datpath );
     if ( datfile.Open( "rb" ) ) {
 
-      icons = new Surface;		// load icons surface
+      icons = new Surface;    // load icons surface
       if ( !icons->LoadImageData( datfile ) ) {
 
         set_icon( *icons, Rect(64, 0, 32, 32) );
 
         view = new View( opts.px_width, opts.px_height, opts.bpp,
                          opts.sdl_flags );
-        if ( view->s_surface && !TTF_Init()) {	// load fonts
+        if ( view->s_surface && !TTF_Init()) {  // load fonts
           int smallsize, largesize;
 
           // use smaller fonts on small displays to prevent text clipping
@@ -388,10 +388,18 @@ static void load_settings( GUIOptions &opts ) {
           else if ( !strncmp( linebuf, "locale", 6 ) ) CFOptions.SetLanguage(val);
           else if ( !strncmp( linebuf, "showdamage", 10 ) ) CFOptions.SetDamageIndicator( atoi(val) != 0 );
           else if ( !strncmp( linebuf, "unlock", 6 ) ) CFOptions.Unlock( val );
+          else if ( !strncmp( linebuf, "listen", 6 ) ) CFOptions.SetLocalPort( atoi(val) );
           else if ( !strncmp( linebuf, "showreplay", 10 ) ) {
             int rep = atoi(val);
             CFOptions.SetTurnReplay( rep != 0 );
             CFOptions.SetQuickReplay( rep == 1 );
+          } else if ( !strncmp( linebuf, "server", 6 ) ) {
+            pos = buf.find( ':', val - linebuf );
+            if ( pos != string::npos )  {
+              buf[pos] = '\0';
+              CFOptions.SetRemotePort( atoi(&linebuf[pos+1]) );
+            }
+            CFOptions.SetRemoteName( val );
           } else if ( !strncmp( linebuf, "keymap", 6 ) ) {
             SDLKey key;
             char *endptr;
@@ -436,6 +444,12 @@ static void save_settings( View *display ) {
     file << StringUtil::strprintf("showdamage %d", CFOptions.GetDamageIndicator()) << '\n';
     file << StringUtil::strprintf("showreplay %d",
             CFOptions.GetTurnReplay() ? (CFOptions.GetQuickReplay() ? 1 : 2) : 0 ) << '\n';
+    if ( CFOptions.GetRemoteName() ) {
+      file << StringUtil::strprintf(
+              StringUtil::strprintf("server %s:%d", CFOptions.GetRemotePort()),
+              CFOptions.GetRemoteName()) << '\n';
+    }
+    file << StringUtil::strprintf("listen %d", CFOptions.GetLocalPort()) << '\n';
 
     file << "keymap ";
     for (int i = 0; i < KEYBIND_COUNT; ++i)
