@@ -90,11 +90,14 @@ void MapWindow::DrawBack( short x, short y, unsigned short w, unsigned short h )
 //              hex1  - source hex position
 //              hex2  - destination hex position
 //              speed - total time (ms) for the animation
+//              blink - if TRUE make target cursor blink (default is
+//                      FALSE)
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 void MapWindow::MoveHex( unsigned short img, const TileSet &tiles,
-                const Point &hex1, const Point &hex2, unsigned short speed ) {
+                const Point &hex1, const Point &hex2,
+                unsigned short speed, bool blink /* = false */ ) {
   // allocate a new surface where we can store the "background" graphics
   Point psrc = mview->Hex2Pixel( hex1 );
   Point pdst = mview->Hex2Pixel( hex2 );
@@ -108,10 +111,17 @@ void MapWindow::MoveHex( unsigned short img, const TileSet &tiles,
 
   Surface *bgs = new Surface;
   if ( !bgs->Create( bg.w, bg.h, DISPLAY_BPP, 0 ) ) {
-    unsigned long oldticks, ticks = 0;
+    unsigned long oldticks, ticks = 0, blinkticks = 0;
+    Point curp = mview->Cursor();
 
     Blit( bgs, bg, 0, 0 );
 
+    if ( blink && mview->CursorEnabled() ) {
+      mview->DisableCursor();
+      Show( mview->UpdateHex( curp ) );
+      blinkticks = speed / 2;
+    }
+
     oldticks = SDL_GetTicks();
     do {
       short cx, cy;
@@ -126,7 +136,15 @@ void MapWindow::MoveHex( unsigned short img, const TileSet &tiles,
 
       Show( bg );
       bgs->Blit( this, Rect( 0, 0, bg.w, bg.h ), bg.x, bg.y );
+
       ticks = SDL_GetTicks() - oldticks;
+
+      if ( blinkticks && ticks >= blinkticks ) {
+        mview->EnableCursor();
+        Show( mview->UpdateHex( curp ) );
+        blinkticks = 0;
+      }
+
     } while ( ticks < speed );
 
     Show( bg );
@@ -188,6 +206,68 @@ void MapWindow::FadeHex( unsigned short img, const Point &hex, bool in, bool uni
   Show( dest );
 }
 
+////////////////////////////////////////////////////////////////////////
+// NAME       : MapWindow::FlashUnit
+// DESCRIPTION: Make the unit at the target hex flash with white.
+// PARAMETERS : hex   - destination hex position
+//            : times - desired number of times
+// RETURNS    : -
+////////////////////////////////////////////////////////////////////////
+
+void MapWindow::FlashUnit( const Point &hex, unsigned short times ) {
+  unsigned long firstticks, oldticks, ticks;
+  Point pos = mview->Hex2Pixel( hex );
+  const Rect dest( pos.x, pos.y, mview->TileWidth(), mview->TileHeight() );
+  const unsigned int speed = ANIM_SPEED_UNIT * 3 / 2;
+  const unsigned int delay = speed / 3;
+  unsigned short img;
+  bool show_cursor;
+
+  Surface tile;
+  tile.Create( mview->TileWidth(), mview->TileHeight(), DISPLAY_BPP, 0 );
+  tile.SetAlpha( SDL_ALPHA_OPAQUE, SDL_SRCALPHA );
+  tile.SetColorKey( Color(CF_COLOR_WHITE) );
+  tile.DisplayFormat();
+  tile.Flood( Color(CF_COLOR_WHITE) );
+
+  img = mview->GetMap()->GetUnit( hex )->Image();
+  mview->DrawUnit( img, &tile, 0, 0, tile );
+  show_cursor = mview->CursorEnabled() && (mview->Cursor() == hex);
+  if ( show_cursor )
+    mview->DrawTerrain( mview->GetCursorImage(), &tile, 0, 0, tile );
+
+  Surface whitetile;
+  whitetile.Create( mview->TileWidth(), mview->TileHeight(), DISPLAY_BPP, 0 );
+  whitetile.SetAlpha( SDL_ALPHA_OPAQUE / 4, SDL_SRCALPHA );
+  whitetile.DisplayFormat();
+  whitetile.Flood( Color(CF_COLOR_WHITE) );
+
+  for ( int i = 0; i < times; ++i ) {
+    firstticks = oldticks = SDL_GetTicks();
+    do {
+      whitetile.Blit( &tile, whitetile, 0, 0 );
+      if ( show_cursor )
+        mview->DrawTerrain( mview->GetCursorImage(), &tile, 0, 0, tile );
+      tile.Blit( this, tile, pos.x, pos.y );
+      Show( dest );
+
+      ticks = SDL_GetTicks() - firstticks;
+      if ( ticks - oldticks < 30 ) SDL_Delay( 25 );
+      oldticks = ticks;
+    } while ( ticks < delay );
+
+    SDL_Delay( delay );
+
+    mview->DrawUnit( img, &tile, 0, 0, tile );
+    if ( show_cursor )
+      mview->DrawTerrain( mview->GetCursorImage(), &tile, 0, 0, tile );
+    tile.Blit( this, tile, pos.x, pos.y );
+    Show( dest );
+
+    SDL_Delay( delay );
+  }
+}
+
 ////////////////////////////////////////////////////////////////////////
 // NAME       : MapWindow::BoxAvoidHexes
 // DESCRIPTION: Try to place a box on the screen so that it does not
@@ -219,7 +299,7 @@ void MapWindow::BoxAvoidHexes( Rect &box, const Point &hex1, const Point &hex2 )
       return;
     }
   }
-} 
+}
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : MapWindow::DisplayHex
