@@ -68,7 +68,7 @@ public:
   Panel *GetPanel( void ) const { return panel; }
 
   void MoveHex( unsigned short img, const TileSet &tiles, const Point &hex1,
-                const Point &hex2, unsigned short speed );
+                const Point &hex2, unsigned short speed, bool blink = false );
   Point MoveCursor( Direction dir );
   void FadeOutUnit( unsigned short img, const Point &hex )
        { FadeHex( img, hex, false, true ); }
@@ -76,6 +76,7 @@ public:
        { FadeHex( img, hex, true, true ); }
   void FadeInTerrain( unsigned short img, const Point &hex )
        { FadeHex( img, hex, true, false ); }
+  void FlashUnit( const Point &hex, unsigned short times );
 
   void DisplayHex( const Point &hex );
   void BoxAvoidHexes( Rect &rect, const Point &hex1, const Point &hex2 ) const;
