@@ -231,7 +231,7 @@ unsigned short Path::StepsToDest( const Point &pos ) const {
   Direction dir = (Direction)path[index];
   unsigned short steps = 0;
 
-  while ( dir != -1 ) {
+  while ( dir != (Direction)-1 ) {
     map->Dir2Hex( p, dir, p );
     index = map->Hex2Index( p );
     dir = (Direction)path[index];
