@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -41,6 +41,12 @@
 #define CW_MODE_NORMAL    0
 #define CW_MODE_PRODUCTION  1
 
+#ifdef _WIN32_WCE
+# define CW_EXIT_BUTTON_FLAGS  0
+#else
+# define CW_EXIT_BUTTON_FLAGS WIDGET_DEFAULT
+#endif
+
 // node class used by the UnitListWidget
 class ULWNode : public Node {
 public:
@@ -236,7 +242,8 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
   // create buttons
   Surface *icons = view->GetSystemIcons();
   new ButtonWidget( GUI_CLOSE, 10, h - sfont->Height() - 18,
-      width, sfont->Height() + 8, WIDGET_DEFAULT, MSG(MSG_B_EXIT), this );
+      width, sfont->Height() + 8, CW_EXIT_BUTTON_FLAGS,
+      MSG(MSG_B_EXIT), this );
 
   if ( player == &Gam->GetMission()->GetPlayer() ) {
     ButtonWidget *btn;
@@ -245,8 +252,9 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
     if ( (unit && t->IsMedic()) ||
          (!unit && b->IsWorkshop()) ) {
       btn = new ButtonWidget( CH_BUTTON_REPAIR, xoff, yoff,
-                     ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4,
-                     WIDGET_STYLE_GFX, NULL, this );
+            ICON_MINI_WIDTH + 8 + sfont->Width(), ICON_MINI_HEIGHT + 4,
+            WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|WIDGET_ALIGN_WITHIN,
+            "_1", this );
       btn->SetImage( icons, Rect( ICON_MINI_REPAIR1_X, ICON_MINI_REPAIR1_Y,
                                   ICON_MINI_WIDTH, ICON_MINI_HEIGHT ),
                             Rect( ICON_MINI_REPAIR2_X, ICON_MINI_REPAIR2_Y,
@@ -259,8 +267,9 @@ ContainerWindow::ContainerWindow( UnitContainer *container, View *view ) :
     if ( !unit ) {
       if ( b->IsFactory() && (b->UnitProduction() != 0) ) {
         btn = new ButtonWidget( CH_BUTTON_BUILD, xoff, yoff,
-                       ICON_MINI_WIDTH + 4, ICON_MINI_HEIGHT + 4,
-                       WIDGET_STYLE_GFX, NULL, this );
+              ICON_MINI_WIDTH + 8 + sfont->Width(), ICON_MINI_HEIGHT + 4,
+              WIDGET_STYLE_GFX|WIDGET_ALIGN_RIGHT|WIDGET_ALIGN_WITHIN,
+              "_2", this );
         btn->SetImage( icons, Rect( ICON_MINI_BUILD1_X, ICON_MINI_BUILD1_Y,
                                     ICON_MINI_WIDTH, ICON_MINI_HEIGHT ),
                               Rect( ICON_MINI_BUILD2_X, ICON_MINI_BUILD2_Y,
