@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2006 Jens Granseuer
+// Copyright (C) 2002-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ static const char *uselect_labels[] = { "Single Unit", "Unit Type", 0 };
 
 EdEventGenericWindow::EdEventGenericWindow( Event &event,
        Mission &mission, View *view ) :
-       Window(WIN_CENTER, view), event(event), mission(mission) { 
+       Window(WIN_CENTER, view), event(event), mission(mission) {
   // calculate dimensions
   SetSize( MIN(sfont->Width() * 35 + 20, view->Width()),
            MIN(sfont->Height() * 12 + 125, view->Height()) );
@@ -106,7 +106,7 @@ EdEventGenericWindow::EdEventGenericWindow( Event &event,
 
   wdy += wd->Height() + 5;
   wd = new ButtonWidget( B_ID_DEPEND, 5, wdy, wd->Width(), wdh,
-       0, "Depends _on", this );
+       0, "Depends o_n", this );
   wd->SetHook( this );
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
@@ -293,7 +293,7 @@ GUI_Status EdEventGenericWindow::WidgetActivated( Widget *widget, Window *win )
 
 EdEventConfigureWindow::EdEventConfigureWindow( Event &event,
                       Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   static const char *setting_labels[] = {
          "Briefing Player 1", "Briefing Player 2", "Next Map", 0 };
 
@@ -310,7 +310,7 @@ EdEventConfigureWindow::EdEventConfigureWindow( Event &event,
 
   e_msg_but = new ButtonWidget( B_ID_MSG,
        5, wd->TopEdge() + wd->Height() + 5,
-       sfont->Width() * 7 + 10, wdh, 
+       sfont->Width() * 7 + 10, wdh,
        event.GetData(0) == 2 ? WIDGET_DISABLED : 0,
        "_Message", this );
   e_msg_but->SetHook( this );
@@ -404,7 +404,7 @@ const char *EdEventConfigureWindow::GetValueString( void ) const {
 
 EdEventCreateUnitWindow::EdEventCreateUnitWindow( Event &event,
                          Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -447,7 +447,7 @@ EdEventCreateUnitWindow::EdEventCreateUnitWindow( Event &event,
 
   wdx += wd->Width() + sfont->TextWidth("XP Level") + 10;
   wd = new CycleWidget( B_ID_XP, wdx,
-       wd->TopEdge(), w - 5 - wdx, wdh, 0, "_XP Level",
+       wd->TopEdge(), w - 5 - wdx, wdh, 0, "XP _Level",
        (event.GetData(2) & 0x1C0) >> 6, xp_labels, this );
   wd->SetHook( this );
 
@@ -519,28 +519,48 @@ GUI_Status EdEventCreateUnitWindow::WidgetActivated( Widget *widget, Window *win
 
 EdEventDestroyUnitWindow::EdEventDestroyUnitWindow( Event &event,
                       Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
-           sfont->Height() * 4 + 50 );
+           sfont->Height() * 5 + 60 );
 
   Widget *wd;
   unsigned short wdx, wdh = sfont->Height() + 8;
-  char buf[32] = "Error";
+  char buf[32] = "Any";
   static const char *player_labels[] = { "Any", "One", "Two", 0 };
+  Point loc;
 
   wd = new ButtonWidget( B_ID_UNIT, 5, 5,
        sfont->Width() * 4 + 10, wdh, 0, "_Unit", this );
   wd->SetHook( this );
 
   Unit *u = mission.GetUnitByID( event.GetData(0) );
-  if ( u ) sprintf( buf, "%s (%d)", u->Name(), u->ID() );
+  if ( u ) {
+    sprintf( buf, "%s (%d)", u->Name(), u->ID() );
+    loc = Point(0, 0);
+  } else {
+    loc = mission.GetMap().Index2Hex( event.GetData(2) );
+  }
 
   wdx = wd->LeftEdge() + wd->Width() + 5;
   e_unit = new StringWidget( 0, wdx, 5, w - wdx - 5, wdh,
            buf, 30, WIDGET_STR_CONST, NULL, this );
 
+  wdx = 10 + sfont->TextWidth( "X" );
+  e_xpos = new NumberWidget( N_ID_XPOS, wdx, wd->TopEdge() + wdh + 5,
+           sfont->Width() * 4 + 10, wdh, loc.x, 0,
+           mission.GetMap().Width() - 1,
+           WIDGET_ALIGN_LEFT|(u ? WIDGET_DISABLED : 0), "_X", this );
+  e_xpos->SetHook( this );
+
+  wdx += wd->Width() + 10 + sfont->TextWidth( "Y" );
+  e_ypos = new NumberWidget( N_ID_YPOS, wdx, e_xpos->TopEdge(),
+       e_xpos->Width(), wdh, loc.y, 0,
+       mission.GetMap().Height() - 1,
+       WIDGET_ALIGN_LEFT|(u ? WIDGET_DISABLED : 0), "_Y", this );
+  e_ypos->SetHook( this );
+
   wdx = sfont->Width() * 20 + 10;
-  wd = new CycleWidget( B_ID_PLAYER, wdx, wd->Height() + 10,
+  wd = new CycleWidget( B_ID_PLAYER, wdx, e_ypos->TopEdge() + wdh + 10,
        w - wdx - 5, wdh, 0, "Controlled by _Player",
        event.GetData(1) + 1, player_labels, this );
   wd->SetHook( this );
@@ -566,17 +586,42 @@ GUI_Status EdEventDestroyUnitWindow::WidgetActivated( Widget *widget, Window *wi
   case B_ID_UNIT:
     TLWListBuilder::BuildUnitList( mission.GetUnits(), tlist );
     new ListSelectWindow( "Select unit", tlist,
-        event.GetData(0), false, this, B_ID_UNIT_OK, view );
+        event.GetData(0), true, this, B_ID_UNIT_OK, view );
     break;
   case B_ID_UNIT_OK: {
     TLWNode *n = static_cast<ListSelectWindow *>(win)->Selected();
-    event.SetData( 0, n ? n->ID() : -1 );
-    e_unit->SetString( n ? n->Name() : "Error" );
+    if ( n ) {
+      event.SetData( 0, n->ID() );
+      event.SetData( 2, 0 );
+      e_unit->SetString( n->Name() );
+      e_xpos->SetNumber( 0 );
+      e_ypos->SetNumber( 0 );
+      e_xpos->Disable();
+      e_ypos->Disable();
+    } else {
+      event.SetData( 0, -1 );
+      e_unit->SetString( "Any" );
+      e_xpos->Enable();
+      e_ypos->Enable();
+    }
+    e_xpos->Draw();
+    e_ypos->Draw();
+    e_xpos->Show();
+    e_ypos->Show();
     tlist.Clear();
     break; }
   case B_ID_PLAYER:
     event.SetData( 1, static_cast<CycleWidget *>(widget)->GetValue() - 1 );
     break;
+  case N_ID_XPOS:
+  case N_ID_YPOS: {
+    Point loc = mission.GetMap().Index2Hex( event.GetData(2) );
+    if ( widget->ID() == N_ID_XPOS )
+      loc.x = static_cast<NumberWidget *>(widget)->Number();
+    else
+      loc.y = static_cast<NumberWidget *>(widget)->Number();
+    event.SetData( 2, mission.GetMap().Hex2Index(loc) );
+    break; }
   }
 
   return GUI_OK;
@@ -594,7 +639,7 @@ GUI_Status EdEventDestroyUnitWindow::WidgetActivated( Widget *widget, Window *wi
 
 EdEventManipEventWindow::EdEventManipEventWindow( Event &event,
                          Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   static const char *action_labels[] = { "Set flags",
                                          "Clear flags",
                                          "Toggle flags", 0 };
@@ -681,7 +726,7 @@ GUI_Status EdEventManipEventWindow::WidgetActivated( Widget *widget, Window *win
 
 EdEventMessageWindow::EdEventMessageWindow( Event &event, Mission &mission,
                                           View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 15 + 15, view->Width()),
            sfont->Height() * 2 + 25 );
 
@@ -735,7 +780,7 @@ GUI_Status EdEventMessageWindow::WidgetActivated( Widget *widget, Window *win )
 
 EdEventMiningWindow::EdEventMiningWindow( Event &event,
                          Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   static const char *action_labels[] = { "Set supplies",
                                          "Modify supplies",
                                          "Set production",
@@ -848,7 +893,7 @@ void EdEventMiningWindow::SetMiningRange( short action ) const {
 
 EdEventResearchWindow::EdEventResearchWindow( Event &event,
                        Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 25, view->Width()),
            sfont->Height() * 4 + 55 );
 
@@ -938,7 +983,7 @@ GUI_Status EdEventResearchWindow::WidgetActivated( Widget *widget, Window *win )
 ////////////////////////////////////////////////////////////////////////
 
 EdEventScoreWindow::EdEventScoreWindow( Event &event, Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 20 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1024,7 +1069,7 @@ GUI_Status EdEventScoreWindow::WidgetActivated( Widget *widget, Window *win ) {
 
 EdEventSetHexWindow::EdEventSetHexWindow( Event &event, Mission &mission,
                                           View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   const TerrainSet &set = mission.GetTerrainSet();
 
   SetSize( MIN(sfont->Width() * 15 + 15, view->Width()),
@@ -1148,7 +1193,7 @@ void EdEventSetHexWindow::DrawTerrain( unsigned short terrain, bool update ) {
 
 EdEventSetTimerWindow::EdEventSetTimerWindow( Event &event,
                          Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   static const char *offset_labels[] = { "None (absolute)",
                                          "Execution time",
                                          "Trigger configuration", 0 };
@@ -1172,7 +1217,7 @@ EdEventSetTimerWindow::EdEventSetTimerWindow( Event &event,
 
   wdy = wdh + 10;
   wd = new CycleWidget( B_ID_OFFSET, e_event->LeftEdge(), wdy,
-       w - e_event->LeftEdge() - 5, wdh, 0, "_Offset",
+       w - e_event->LeftEdge() - 5, wdh, 0, "O_ffset",
        event.GetData(2), offset_labels, this );
   wd->SetHook( this );
 
@@ -1244,7 +1289,7 @@ GUI_Status EdEventSetTimerWindow::WidgetActivated( Widget *widget, Window *win )
 
 EdTrigHaveCrystalsWindow::EdTrigHaveCrystalsWindow( Event &event,
                       Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1353,7 +1398,7 @@ GUI_Status EdTrigHaveCrystalsWindow::WidgetActivated( Widget *widget, Window *wi
 
 EdTrigHaveShopWindow::EdTrigHaveShopWindow( Event &event,
                       Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1432,7 +1477,7 @@ GUI_Status EdTrigHaveShopWindow::WidgetActivated( Widget *widget, Window *win )
 
 EdTrigHaveUnitWindow::EdTrigHaveUnitWindow( Event &event,
                       Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1511,7 +1556,7 @@ GUI_Status EdTrigHaveUnitWindow::WidgetActivated( Widget *widget, Window *win )
 ////////////////////////////////////////////////////////////////////////
 
 EdTrigTimerWindow::EdTrigTimerWindow( Event &event, View *view ) :
-                  Window(WIN_CENTER, view), event(event) { 
+                  Window(WIN_CENTER, view), event(event) {
   SetSize( MIN(sfont->Width() * 21 + 15, view->Width()),
            sfont->Height() * 2 + 30 );
 
@@ -1553,7 +1598,7 @@ GUI_Status EdTrigTimerWindow::WidgetActivated( Widget *widget, Window *win ) {
 
 EdTrigUnitDestroyedWindow::EdTrigUnitDestroyedWindow( Event &event,
                            Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1676,7 +1721,7 @@ GUI_Status EdTrigUnitDestroyedWindow::WidgetActivated( Widget *widget, Window *w
 
 EdTrigUnitPositionWindow::EdTrigUnitPositionWindow( Event &event,
                            Mission &mission, View *view ) :
-      Window(WIN_CENTER, view), event(event), mission(mission) { 
+      Window(WIN_CENTER, view), event(event), mission(mission) {
   SetSize( MIN(sfont->Width() * 30 + 15, view->Width()),
            sfont->Height() * 4 + 50 );
 
@@ -1805,7 +1850,7 @@ GUI_Status EdTrigUnitPositionWindow::WidgetActivated( Widget *widget, Window *wi
 ////////////////////////////////////////////////////////////////////////
 
 EdTrigHandicapWindow::EdTrigHandicapWindow( Event &event, View *view ) :
-                  Window(WIN_CENTER, view), event(event) { 
+                  Window(WIN_CENTER, view), event(event) {
   SetSize( MIN(sfont->Width() * 20 + DEFAULT_CBW_SIZE + 15, view->Width()),
            sfont->Height() * 4 + 40 );
 
