@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2006 Jens Granseuer
+// Copyright (C) 2002-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -397,6 +397,20 @@ GUI_Status NewMissionWindow::WidgetActivated( Widget *button, Window *win ) {
           gen.Generate( mission->GetMap(),
               gen_water->Level(), gen_roughness->Level() );
         }
+
+        // add the most basic messages
+        Language en;
+        en.SetID( CF_LANG_DEFAULT );
+        en.AddMsg( "Unnamed" );   // map name
+        en.AddMsg( "Player 1" );  // name player 1
+        en.AddMsg( "Player 2" );  // name player 2
+        en.AddMsg( "HQ 1" );      // HQ player 1
+        en.AddMsg( "HQ 2" );      // HQ player 2
+        mission->GetMessages().AddLanguage( en );
+        mission->SetName( 0 );
+        mission->GetPlayer( PLAYER_ONE ).SetNameID( 1 );
+        mission->GetPlayer( PLAYER_TWO ).SetNameID( 2 );
+
         // use the button ID supplied by the caller
         button->SetID( ok_id );
         hook->WidgetActivated( button, this );
@@ -893,7 +907,7 @@ EdUnitWindow::EdUnitWindow( Unit &unit, Mission &mission, View *view ) :
 
   xoff = w/2 + 10 + sfont->TextWidth("XP Level");
   wd = new CycleWidget( B_ID_XP, xoff, yoff, w - 5 - xoff, wdh,
-                        0, "_XP Level", u.XPLevel(), xp_labels, this );
+                        0, "XP _Level", u.XPLevel(), xp_labels, this );
   wd->SetHook( this );
 
   yoff += 5 + wdh;
