@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2006 Jens Granseuer
+// Copyright (C) 2002-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ void GfxWidget::Init( unsigned short gfxw, unsigned short gfxh, unsigned short i
   if ( slider ) {
     slider->Adjust( 0, rows - visrows, visrows );
     slider->ScrollTo( 0 );
-  } else { 
+  } else {
     // create the corresponding slider widget
     slider = new SliderWidget( 0, x + w - DEFAULT_SLIDER_SIZE, y,
        DEFAULT_SLIDER_SIZE, h, 0, rows - visrows, toprow, visrows,
@@ -151,7 +151,7 @@ GUI_Status GfxWidget::Select( short item ) {
       if ( selrow < toprow ) newtop = selrow;
       else if ( selrow + ItemHeight() >= newtop + visrows )
         newtop = selrow - visrows + ItemHeight();
-    } else newtop = 0;
+    }
 
     if ( toprow != newtop ) {
       static_cast<SliderWidget *>( GetWidget(0) )->ScrollTo( newtop );
@@ -184,17 +184,28 @@ GUI_Status GfxWidget::WidgetActivated( Widget *widget, Window *win ) {
 
 ////////////////////////////////////////////////////////////////////////
 // NAME       : GfxWidget::MouseDown
-// DESCRIPTION: Select an image.
+// DESCRIPTION: Select an image or scroll the list.
 // PARAMETERS : button - SDL_MouseButtonEvent received from the event
 //                       handler
 // RETURNS    : GUI status
 ////////////////////////////////////////////////////////////////////////
 
 GUI_Status GfxWidget::MouseDown( const SDL_MouseButtonEvent &button ) {
-  GUI_Status rc = CompositeWidget::MouseDown( button );
-  if ( rc != GUI_OK ) return rc;
+  SDL_MouseButtonEvent mybutton = button;
+  if ( ((button.button == SDL_BUTTON_WHEELUP) ||
+       (button.button == SDL_BUTTON_WHEELDOWN)) &&
+       Contains( button.x - surface->LeftEdge(), button.y - surface->TopEdge() ) ) {
+    // reroute all wheel events to the scroller
+    SliderWidget *s = static_cast<SliderWidget *>( GetWidget(0) );
+    if ( s ) {
+      mybutton.x = s->LeftEdge() + surface->LeftEdge();
+      mybutton.y = s->TopEdge() + surface->TopEdge();
+    }
+  }
 
-  if ( button.button == SDL_BUTTON_LEFT ) {
+  GUI_Status rc = CompositeWidget::MouseDown( mybutton );
+
+  if ( (rc == GUI_OK) && (button.button == SDL_BUTTON_LEFT) ) {
     short mx = button.x - surface->LeftEdge();
     short my = button.y - surface->TopEdge();
 
@@ -206,7 +217,7 @@ GUI_Status GfxWidget::MouseDown( const SDL_MouseButtonEvent &button ) {
       if ( item < items ) return Select( item );
     }
   }
-  return GUI_OK;
+  return rc;
 }
 
 ////////////////////////////////////////////////////////////////////////
