@@ -1,5 +1,5 @@
 // CoMET - The Crimson Fields Map Editing Tool
-// Copyright (C) 2002-2006 Jens Granseuer
+// Copyright (C) 2002-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -944,7 +944,7 @@ unsigned short Mission::ValidateEvent( Event &e, stringstream &errors ) const {
   case EVENT_SET_HEX:
     break;
   case EVENT_DESTROY_UNIT:
-    if ((e.GetData(0) == -1) || !GetUnitByID(e.GetData(0))) {
+    if ((e.GetData(0) >= 0) && !GetUnitByID(e.GetData(0))) {
       ++errs;
       errors << "Error: Invalid unit " << e.GetData(0) << " for "
              << e.Name() << " (" << (short)e.ID() << ") event.\n\n";
@@ -1138,9 +1138,9 @@ Event::Event( unsigned char id, unsigned char type, unsigned char trigger ) {
                           // face northwards, MAX_GROUP_SIZE, no xp
     break;
   case EVENT_DESTROY_UNIT:
-    e_data[0] = -1;       // destroy unit -1
-    e_data[1] = -1;        // any owner
-    e_data[2] = 0;
+    e_data[0] = -1;       // destroy any unit
+    e_data[1] = -1;       // any owner
+    e_data[2] = 0;        // at position 0/0
     break;
   case EVENT_MANIPULATE_EVENT:
     e_data[0] = -1;      // modify event -1
@@ -1360,6 +1360,7 @@ int Event::Export( ofstream &file, const Map &map ) const {
   case EVENT_DESTROY_UNIT:
     file << "unit = " << e_data[0] << '\n';
     file << "owner = " << (e_data[1] == -1 ? -1 : e_data[1] + 1) << '\n';
+    file << "pos = " << e_data[2] << '\n';
     break;
   case EVENT_MANIPULATE_EVENT:
     file << "event = " << e_data[0] << '\n';
