@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -34,8 +34,8 @@
 void TLWListBuilder::BuildEventList( const List &events, TLWList &tlw ) {
   for ( Event *e = static_cast<Event *>( events.Head() ); e;
         e = static_cast<Event *>(e->Next()) ) {
-    char buf[48];
-    sprintf( buf, "%s (%d)", e->Name(), e->ID() );
+    char buf[64];
+    sprintf( buf, "%s / %s (%d)", e->Name(), e->TriggerName(), e->ID() );
     tlw.InsertNodeSorted( new TLWNode(buf, e, e->ID()) );
   }
 }
@@ -44,8 +44,8 @@ void TLWListBuilder::BuildEventList( const List &events, TLWList &tlw ) {
 // NAME       : TLWListBuilder::BuildUnitList
 // DESCRIPTION: Use the units list to create a second list which can
 //              be displayed by a TextListWidget.
-// PARAMETERS : events - list of units
-//              tlw    - list of TLWNodes to be filled
+// PARAMETERS : units - list of units
+//              tlw   - list of TLWNodes to be filled
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
@@ -64,9 +64,9 @@ void TLWListBuilder::BuildUnitList( const List &units, TLWList &tlw ) {
 //              be displayed by a TextListWidget. Only include units at
 //              the given hex coordinates which are inside a unit
 //              container.
-// PARAMETERS : events - list of units
-//              tlw    - list of TLWNodes to be filled
-//              pos    - requested hex position
+// PARAMETERS : units - list of units
+//              tlw   - list of TLWNodes to be filled
+//              pos   - requested hex position
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
@@ -87,14 +87,14 @@ void TLWListBuilder::BuildUnitList( const List &units, TLWList &tlw,
 // DESCRIPTION: Use the buildings list to create a second list which can
 //              be displayed by a TextListWidget.
 // PARAMETERS : shops - list of buildings
-//              tlw    - list of TLWNodes to be filled
+//              tlw   - list of TLWNodes to be filled
 // RETURNS    : -
 ////////////////////////////////////////////////////////////////////////
 
 void TLWListBuilder::BuildShopList( const List &shops, TLWList &tlw ) {
   for ( Building *b = static_cast<Building *>( shops.Head() ); b;
         b = static_cast<Building *>(b->Next()) ) {
-    char buf[28];
+    char buf[40];
     sprintf( buf, "%s (%d)", b->Name(), b->ID() );
     tlw.InsertNodeSorted( new TLWNode(buf, b, b->ID()) );
   }
