@@ -23,7 +23,9 @@
 #ifndef _INCLUDE_FILEIO_H
 #define _INCLUDE_FILEIO_H
 
-#if HAVE_DIRENT_H
+#if defined WIN32
+# include <windows.h>
+#elif HAVE_DIRENT_H
 # include <dirent.h>
 #elif HAVE_SYS_NDIR_H
 # include <sys/ndir.h>
@@ -31,8 +33,6 @@
 # include <sys/dir.h>
 #elif HAVE_NDIR_H
 # include <ndir.h>
-#elif defined WIN32
-# include <windows.h>
 #endif
 
 #include <string>
