@@ -1,5 +1,5 @@
 // Crimson Fields -- a game of tactical warfare
-// Copyright (C) 2000-2006 Jens Granseuer
+// Copyright (C) 2000-2007 Jens Granseuer
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -45,24 +45,25 @@ enum GUI_Status { GUI_ERROR = -6, GUI_RESTART, GUI_QUIT, GUI_CLOSE, GUI_NONE, GU
 #define WIDGET_ALIGN_LEFT     0x0020
 #define WIDGET_ALIGN_RIGHT    0x0040
 #define WIDGET_ALIGN_TOP      0x0080
+#define WIDGET_ALIGN_WITHIN   0x0100  // must be combined with _LEFT or _RIGHT to be useful
 
 // for buttons mostly; some combinations are not allowed (e.g. SUBMENU and GFX)
 #define WIDGET_STYLE_STD       0x0000 // standard bevelled box
-#define WIDGET_STYLE_NOBORDER  0x0100 // don't draw widget borders
-#define WIDGET_STYLE_GFX       0x0200 // use images
-#define WIDGET_STYLE_MENU      0x0400 // kind of combination of NOBORDER and STD
-#define WIDGET_STYLE_SUBMENU   0x0800 // display sub-menu indicator
-#define WIDGET_STYLE_HIGHLIGHT 0x1000 // use highlight instead of background color
+#define WIDGET_STYLE_NOBORDER  0x0200 // don't draw widget borders
+#define WIDGET_STYLE_GFX       0x0400 // use images
+#define WIDGET_STYLE_MENU      0x0800 // kind of combination of NOBORDER and STD
+#define WIDGET_STYLE_SUBMENU   0x1000 // display sub-menu indicator
+#define WIDGET_STYLE_HIGHLIGHT 0x2000 // use highlight instead of background color
 
 // for string widgets
-#define WIDGET_STR_CONST      0x0400  // string in widget cannot be modified
-#define WIDGET_STR_PASSWORD   0x0800  // display string as asterisks
+#define WIDGET_STR_CONST      0x4000  // string in widget cannot be modified
+#define WIDGET_STR_PASSWORD   0x8000  // display string as asterisks
 
 // for scrollers
-#define WIDGET_HSCROLL        0x0200  // horizontal slider
-#define WIDGET_VSCROLL        0x0400  // vertical slider
-#define WIDGET_HSCROLLKEY     0x0800  // scroller supports left/right cursor keys
-#define WIDGET_VSCROLLKEY     0x1000  // scroller supports up/down cursor keys
+#define WIDGET_HSCROLL        0x1000  // horizontal slider
+#define WIDGET_VSCROLL        0x2000  // vertical slider
+#define WIDGET_HSCROLLKEY     0x4000  // scroller supports left/right cursor keys
+#define WIDGET_VSCROLLKEY     0x8000  // scroller supports up/down cursor keys
 
 
 class WidgetHook;
@@ -116,7 +117,8 @@ protected:
   Window *surface;
   unsigned short flags;
   short id;
-  short key;			// keystroke to activate widget
+  short key;      // keystroke to activate widget
+  short keypos;
 
   Font *font;
   string title;
@@ -169,5 +171,5 @@ private:
 
 #include "window.h"
 
-#endif	/* _INCLUDE_WIDGET_H */
+#endif  /* _INCLUDE_WIDGET_H */
 
