@@ -1,5 +1,5 @@
 /* cfed -- a level editor for Crimson Fields
-   Copyright (C) 2000-2006 Jens Granseuer
+   Copyright (C) 2000-2007 Jens Granseuer
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -576,6 +576,13 @@ int EventHandler::ParseSection( ifstream &in, const string *opt, unsigned long &
           case EVENT_DESTROY_UNIT:
             if ( key == "unit" ) e->SetData(0, StrToNum(val));         // id of unit to destroy
             else if ( key == "owner" ) e->SetData(1, StrToNum(val)-1); // unit owner
+            else if ( key == "pos" ) {                                 // unit position
+              loc = ParseCoords(val);
+              if ( (loc.x < 0) || (loc.y < 0) ) {
+                rc = 1;
+                cerr << "Error near line " << line << ": Invalid position " << val << endl;
+              } else e->SetData(2, m.GetMap().Hex2Index(loc));
+            }
             break;
 
           case EVENT_MANIPULATE_EVENT:
@@ -1450,14 +1457,19 @@ int MissionParser::check_events( void ) const {
         break;
       case EVENT_DESTROY_UNIT:
         if ( e->GetData(0) < 0 ) {
-          cerr << "Error: No unit specified for Destroy Unit event " << (short)e->ID() << endl;
-          return 1;
-        }
+          if (e->GetData(2) == -9999) {
+            cerr << "Error: No target specified for Destroy Unit event " << (short)e->ID() << endl;
+            return 1;
+          }
+          e->SetData(0, -1);
+        } else {
 
-        if ( !GetUnitByID( e->GetData(0) ) ) {
-          cerr << "Error: Unit with ID " << e->GetData(0) << " specified in event "
-               << (short)e->ID() << " does not exist" << endl;
-          return 1;
+          if ( !GetUnitByID( e->GetData(0) ) ) {
+            cerr << "Error: Unit with ID " << e->GetData(0) << " specified in event "
+                 << (short)e->ID() << " does not exist" << endl;
+            return 1;
+          }
+          e->SetData(2, 0);
         }
 
         if ( e->GetData(1) < -1 ) e->SetData(1, -1);
@@ -1465,8 +1477,6 @@ int MissionParser::check_events( void ) const {
           cerr << "Error: Invalid unit owner for event " << (short)e->ID() << endl;
           return 1;
         }
-
-        e->SetData(2, 0);
         break;
       case EVENT_MANIPULATE_EVENT:
         if ( e->GetData(0) < 0 ) {
